==> neptune-client-0.14.0.tar.gz: neptune-client-0.14.0/neptune/new/internal/operation_processors/sync_operation_processor.py <==
#
# Copyright (c) 2020, Neptune Labs Sp. z o.o.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import Optional

from neptune.new.internal.backends.neptune_backend import NeptuneBackend
from neptune.new.internal.container_type import ContainerType
from neptune.new.internal.operation import Operation
from neptune.new.internal.operation_processors.operation_processor import (
    OperationProcessor,
)


class SyncOperationProcessor(OperationProcessor):
    def __init__(
        self, container_id: str, container_type: ContainerType, backend: NeptuneBackend
    ):
        self._container_id = container_id
        self._container_type = container_type
        self._backend = backend

    def enqueue_operation(self, op: Operation, wait: bool) -> None:
        # pylint: disable=unused-argument
        _, errors = self._backend.execute_operations(
            self._container_id, self._container_type, [op]
        )
        if errors:
            raise errors[0]

    def wait(self):
        pass

    def flush(self):
        pass

    def start(self):
        pass

    def stop(self, seconds: Optional[float] = None):
        pass

==> neptune-client-0.16.5.tar.gz: neptune-client-0.16.5/neptune/new/internal/operation_processors/sync_operation_processor.py <==
#
# Copyright (c) 2020, Neptune Labs Sp. z o.o.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import Optional

from neptune.new.internal.backends.neptune_backend import NeptuneBackend
from neptune.new.internal.container_type import ContainerType
from neptune.new.internal.operation import Operation
from neptune.new.internal.operation_processors.operation_processor import (
    OperationProcessor,
)


class SyncOperationProcessor(OperationProcessor):
    def __init__(self, container_id: str, container_type: ContainerType, backend: NeptuneBackend):
        self._container_id = container_id
        self._container_type = container_type
        self._backend = backend

    def enqueue_operation(self, op: Operation, wait: bool) -> None:
        # pylint: disable=unused-argument
        _, errors = self._backend.execute_operations(self._container_id, self._container_type, [op])
        if errors:
            raise errors[0]

    def wait(self):
        pass

    def flush(self):
        pass

    def start(self):
        pass

    def stop(self, seconds: Optional[float] = None):
        pass
